@@ -10,7 +10,7 @@ def test_express_pattern(datadir):
 
     result_keys = [str(i) for i in result.keys()]
 
-    expected_keys = ["<PERSON> 在 <GPE> 的 <ORG> 读 书 。", "来 一 首 <歌手名> 的 歌 。"]
+    expected_keys = ["`PERSON`在`GPE`的`ORG`读书。", "来一首`歌手名`的歌。"]
 
     for r, e in zip(result_keys, expected_keys):
         assert e in r
@@ -19,10 +19,10 @@ def test_express_pattern(datadir):
 
     expected_value = [
         [
-            "[王 小 明](PERSON) 在 [北 京](GPE) 的 [清 华 大 学](ORG) 读 书 。",
-            "[王 小 明](PERSON) 在 [台 北 新 竹](GPE) 的 [清 华 大 学](ORG) 读 书 。",
+            "[王小明](PERSON)在[北京](GPE)的[清华大学](ORG)读书。",
+            "[王小明](PERSON)在[台北新竹](GPE)的[清华大学](ORG)读书。",
         ],
-        ["来 一 首 [蓝 泽 雨](歌手名) 的 歌 。"],
+        ["来一首[蓝泽雨](歌手名)的歌。"],
     ]
 
     for i, value in enumerate(result_value):
